@@ -26,15 +26,15 @@ class Circle(Model):
     description = models.CharField(max_length=255, blank=True)
     creationDate = models.DateField(auto_now_add=True)
     status = models.CharField(max_length=8, choices=STATUS_CHOICES, default='Public')
-    team = models.ManyToManyField(settings.AUTH_USER_MODEL, through="CircleMember", blank=True)
-    owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_circles", on_delete=models.DO_NOTHING,
+    owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_circles", on_delete=models.SET_NULL,
                               null=True, blank=True)
     jabberID = models.CharField(max_length=255, blank=True, null=True, unique=True)
     jabberRoom = models.BooleanField(default=True)
 
     class Meta(Model.Meta):
+        empty_containers = ["owner"]
         auto_author = 'owner'
-        nested_fields = ["team", 'members']
+#        depth = 1 # Disabled due to owner being serialized
         permission_classes = [CirclePermissions]
         anonymous_perms = []
         authenticated_perms = []
